using System;

namespace IFOInfo
{
    /// <summary>
    /// Summary description for Class1.
    /// </summary>
    class Class1
    {
        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main(string[] args)
        {
            if (args.Length < 1)
            {
                Usage();
                return;
            }

            IICommandLine cmdLine = new IICommandLine(args);

            Console.Write(cmdLine.Errors);

            if (!cmdLine.Valid)
                return;

            IFOFile ifoFile = new IFOFile(cmdLine.IFOFile);

            if (!ifoFile.Valid)
            {
                Console.WriteLine(ifoFile.Errors);
                return;
            }

            ifoFile.Format = IFOInfo.ChapterFormat.Frames;
            if (cmdLine.UseHMS)
                ifoFile.Format = IFOInfo.ChapterFormat.HMS;

            ifoFile.FPS = cmdLine.FPS;

            IFOFile.ChapterList[] chapters = ifoFile.GetChapterList();

            if (cmdLine.UseLongestPGC)
            {
                int iLength = 0;
                string strUse = "";

                foreach(IFOFile.ChapterList cl in chapters)
                {
                    if (cl.iMaxTime > iLength)
                    {
                        iLength = cl.iMaxTime;
                        strUse = cl.Chapters;
                    }
                }

                Console.Write(strUse);
            }
            else if (cmdLine.PGC < 0)
            {
                int iNumValidLists = 0;
                foreach(IFOFile.ChapterList cl in chapters)
                {
                    if (cl.iNumChapters > cmdLine.ChapterMinimum)
                        iNumValidLists++;
                }

                foreach(IFOFile.ChapterList cl in chapters)
                {
                    if (cl.iNumChapters >= cmdLine.ChapterMinimum)
                    {
                        if (cmdLine.AlwaysDisplayPGC || iNumValidLists > 1)
                            Console.WriteLine("[Program Chain {0}]", cl.ProgramChain);
                        Console.WriteLine(cl.Chapters);
                    }
                }
            }
            else
            {
                bool bFound = false;
                foreach(IFOFile.ChapterList cl in chapters)
                {
                    if (cmdLine.PGC == cl.ProgramChain)
                    {
                        bFound = true;
                        Console.Write(cl.Chapters);
                    }
                }
                if (!bFound)
                {
                    Console.WriteLine("Error:  Could not locate program chain {0}", cmdLine.PGC);
                }
            }
        }

        static void Usage()
        {
            Console.WriteLine(
"IFOInfo, version {0}\n" + 
"\n" + 
"Usage:    {1} [-chl] [-p pgc] [-f FPS] [-m min] <IFO File>\n" + 
"\n" + 
"Options:  -f   Set assumed framerate to FPS (default: 23.976)\n" + 
"          -c   Dump the chapter list (default)\n" + 
"          -p   Dump program chain number \"pgc\" (default: all)\n" +
"          -l   Dump only the PGC with the most entries (overrides -p)\n" +
"          -h   Use hh:mm:ss:fff format (default: frames)\n" + 
"          -m   Display only lists with at least \"min\" entries (default: 3)\n" + 
"          -d   Display the PGC number even if there is only one list\n" +
                "", IIGlobal.GetVersion(), Environment.GetCommandLineArgs()[0]);
        }

    }
}
